|MPL-Data-Cast|
===============

|PyPI Version| |Build Status| |Coverage Status| |Docs Status|


Documentation
-------------

The documentation, including the code reference and examples, is available at
`mpl-data-cast.readthedocs.io <https://mpl-data-cast.readthedocs.io>`__.


Installation
------------
..
   Installers for Windows and macOS are available at the `release page <https://github.com/GuckLab/MPL-Data-Cast/releases>`__.

If you have Python 3 installed, you can install MPL-Data-Cast with

::

    pip install mpl_data_cast


Testing
-------

::

    pip install -e .
    pip install -r tests/requirements.txt
    pytest tests


.. |MPL-Data-Cast| image:: https://raw.github.com/GuckLab/MPL-Data-Cast/master/docs/logo/MPL-Data-Cast_h50.png
.. |PyPI Version| image:: https://img.shields.io/pypi/v/MPL-Data-Cast.svg
   :target: https://pypi.python.org/pypi/MPL-Data-Cast
.. |Build Status| image:: https://img.shields.io/github/actions/workflow/status/GuckLab/MPL-Data-Cast/check.yml
   :target: https://github.com/GuckLab/MPL-Data-Cast/actions?query=workflow%3AChecks
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/GuckLab/MPL-Data-Cast/master.svg
   :target: https://codecov.io/gh/GuckLab/MPL-Data-Cast
.. |Docs Status| image:: https://img.shields.io/readthedocs/mpl-data-cast
   :target: https://readthedocs.org/projects/mpl-data-cast/builds/
